@@ -1,6 +1,7 @@
 package helpers
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"strconv"
@@ -15,6 +16,7 @@ import (
 	"github.com/openshift/cluster-logging-operator/pkg/k8shandler"
 	"github.com/openshift/cluster-logging-operator/pkg/logger"
 	"github.com/openshift/cluster-logging-operator/pkg/utils"
+	"github.com/openshift/cluster-logging-operator/test/helpers/oc"
 )
 
 type fluentReceiverLogStore struct {
@@ -27,7 +29,7 @@ const (
 	receiverName             = "fluent-receiver"
 	secureFluentConfTemplate = `
 <system>
-	@log_level info
+	log_level info
 </system>
 <source>
   @type forward
@@ -64,7 +66,7 @@ const (
 	`
 	unsecureFluentConf = `
 <system>
-	@log_level warn
+	log_level warn
 </system>
 <source>
   @type forward
@@ -97,7 +99,7 @@ func (fluent *fluentReceiverLogStore) hasLogs(file string, timeToWait time.Durat
 	options := metav1.ListOptions{
 		LabelSelector: "component=fluent-receiver",
 	}
-	pods, err := fluent.tc.KubeClient.CoreV1().Pods(OpenshiftLoggingNS).List(options)
+	pods, err := fluent.tc.KubeClient.CoreV1().Pods(OpenshiftLoggingNS).List(context.TODO(), options)
 	if err != nil {
 		return false, err
 	}
@@ -107,10 +109,11 @@ func (fluent *fluentReceiverLogStore) hasLogs(file string, timeToWait time.Durat
 	logger.Debugf("Pod %s", pods.Items[0].Name)
 	cmd := fmt.Sprintf("ls %s | wc -l", file)
 
-	err = wait.Poll(defaultRetryInterval, timeToWait, func() (done bool, err error) {
+	err = wait.PollImmediate(defaultRetryInterval, timeToWait, func() (done bool, err error) {
 		output, err := fluent.tc.PodExec(OpenshiftLoggingNS, pods.Items[0].Name, "fluent-receiver", []string{"bash", "-c", cmd})
 		if err != nil {
-			return false, err
+			logger.Errorf("Error polling fluent-receiver for logs: %v", err)
+			return false, nil
 		}
 		value, err := strconv.Atoi(strings.TrimSpace(output))
 		if err != nil {
@@ -129,7 +132,7 @@ func (fluent *fluentReceiverLogStore) logs(file string, timeToWait time.Duration
 	options := metav1.ListOptions{
 		LabelSelector: "component=fluent-receiver",
 	}
-	pods, err := fluent.tc.KubeClient.CoreV1().Pods(OpenshiftLoggingNS).List(options)
+	pods, err := fluent.tc.KubeClient.CoreV1().Pods(OpenshiftLoggingNS).List(context.TODO(), options)
 	if err != nil {
 		return "", err
 	}
@@ -137,11 +140,12 @@ func (fluent *fluentReceiverLogStore) logs(file string, timeToWait time.Duration
 		return "", errors.New("No pods found for fluent receiver")
 	}
 	logger.Debugf("Pod %s", pods.Items[0].Name)
-	cmd := fmt.Sprintf("cat %s", file)
+	cmd := fmt.Sprintf("cat %s | awk -F '\t' '{print $3}'| head -n 1", file)
 	result := ""
-	err = wait.Poll(defaultRetryInterval, timeToWait, func() (done bool, err error) {
+	err = wait.PollImmediate(defaultRetryInterval, timeToWait, func() (done bool, err error) {
 		if result, err = fluent.tc.PodExec(OpenshiftLoggingNS, pods.Items[0].Name, "fluent-receiver", []string{"bash", "-c", cmd}); err != nil {
-			return false, err
+			logger.Errorf("Failed to fetch logs from fluent-receiver %v", err)
+			return false, nil
 		}
 		return true, nil
 	})
@@ -151,8 +155,13 @@ func (fluent *fluentReceiverLogStore) logs(file string, timeToWait time.Duration
 	return result, nil
 }
 
-func (fluent *fluentReceiverLogStore) ApplicationLogs(timeToWait time.Duration) (string, error) {
-	return fluent.logs("/tmp/app-logs", timeToWait)
+func (fluent *fluentReceiverLogStore) ApplicationLogs(timeToWait time.Duration) (logs, error) {
+	fl, err := fluent.logs("/tmp/app-logs", timeToWait)
+	if err != nil {
+		return nil, err
+	}
+	out := "[" + strings.TrimRight(strings.Replace(fl, "\n", ",", -1), ",") + "]"
+	return ParseLogs(out)
 }
 
 func (fluent fluentReceiverLogStore) HasInfraStructureLogs(timeToWait time.Duration) (bool, error) {
@@ -166,22 +175,47 @@ func (fluent *fluentReceiverLogStore) HasAuditLogs(timeToWait time.Duration) (bo
 	return fluent.hasLogs("/tmp/audit.logs", timeToWait)
 }
 
-func (es *fluentReceiverLogStore) GrepLogs(expr string, timeToWait time.Duration) (string, error) {
+func (fluent *fluentReceiverLogStore) GrepLogs(expr string, timeToWait time.Duration) (string, error) {
 	return "Not Found", fmt.Errorf("Not implemented")
 }
 
+func (fluent *fluentReceiverLogStore) RetrieveLogs() (map[string]string, error) {
+	result := map[string]string{
+		"infra": "",
+		"audit": "",
+		"app":   "",
+	}
+	var err error
+	for key := range result {
+		var s string
+		s, err = fluent.logs(fmt.Sprintf("/tmp/%s.logs", key), 30*time.Second)
+		if err != nil {
+			continue
+		}
+		result[key] = s
+	}
+	return result, err
+}
+
+func (fluent *fluentReceiverLogStore) ClusterLocalEndpoint() string {
+	panic("Not implemented")
+}
+
 func (tc *E2ETestFramework) createServiceAccount() (serviceAccount *corev1.ServiceAccount, err error) {
+	opts := metav1.CreateOptions{}
 	serviceAccount = k8shandler.NewServiceAccount("fluent-receiver", OpenshiftLoggingNS)
-	if serviceAccount, err = tc.KubeClient.Core().ServiceAccounts(OpenshiftLoggingNS).Create(serviceAccount); err != nil {
+	if serviceAccount, err = tc.KubeClient.CoreV1().ServiceAccounts(OpenshiftLoggingNS).Create(context.TODO(), serviceAccount, opts); err != nil {
 		return nil, err
 	}
 	tc.AddCleanup(func() error {
-		return tc.KubeClient.Core().ServiceAccounts(OpenshiftLoggingNS).Delete(serviceAccount.Name, nil)
+		opts := metav1.DeleteOptions{}
+		return tc.KubeClient.CoreV1().ServiceAccounts(OpenshiftLoggingNS).Delete(context.TODO(), serviceAccount.Name, opts)
 	})
 	return serviceAccount, nil
 }
 
 func (tc *E2ETestFramework) createRbac(name string) (err error) {
+	opts := metav1.CreateOptions{}
 	saRole := k8shandler.NewRole(
 		name,
 		OpenshiftLoggingNS,
@@ -194,11 +228,12 @@ func (tc *E2ETestFramework) createRbac(name string) (err error) {
 			),
 		),
 	)
-	if _, err = tc.KubeClient.Rbac().Roles(OpenshiftLoggingNS).Create(saRole); err != nil {
+	if _, err = tc.KubeClient.RbacV1().Roles(OpenshiftLoggingNS).Create(context.TODO(), saRole, opts); err != nil {
 		return err
 	}
 	tc.AddCleanup(func() error {
-		return tc.KubeClient.Rbac().Roles(OpenshiftLoggingNS).Delete(name, nil)
+		opts := metav1.DeleteOptions{}
+		return tc.KubeClient.RbacV1().Roles(OpenshiftLoggingNS).Delete(context.TODO(), name, opts)
 	})
 	subject := k8shandler.NewSubject(
 		"ServiceAccount",
@@ -213,11 +248,12 @@ func (tc *E2ETestFramework) createRbac(name string) (err error) {
 			subject,
 		),
 	)
-	if _, err = tc.KubeClient.Rbac().RoleBindings(OpenshiftLoggingNS).Create(roleBinding); err != nil {
+	if _, err = tc.KubeClient.RbacV1().RoleBindings(OpenshiftLoggingNS).Create(context.TODO(), roleBinding, opts); err != nil {
 		return err
 	}
 	tc.AddCleanup(func() error {
-		return tc.KubeClient.Rbac().RoleBindings(OpenshiftLoggingNS).Delete(name, nil)
+		opts := metav1.DeleteOptions{}
+		return tc.KubeClient.RbacV1().RoleBindings(OpenshiftLoggingNS).Delete(context.TODO(), name, opts)
 	})
 	return nil
 }
@@ -271,11 +307,12 @@ func (tc *E2ETestFramework) DeployFluentdReceiver(rootDir string, secure bool) (
 		otherConf := map[string][]byte{
 			"shared_key": []byte("my_shared_key"),
 		}
-		if _, logStore.pipelineSecret, err = tc.CreatePipelineSecret(rootDir, receiverName, receiverName, otherConf); err != nil {
+		if logStore.pipelineSecret, err = tc.CreatePipelineSecret(rootDir, receiverName, receiverName, otherConf); err != nil {
 			return nil, err
 		}
 		tc.AddCleanup(func() error {
-			return tc.KubeClient.Core().Secrets(OpenshiftLoggingNS).Delete(receiverName, nil)
+			opts := metav1.DeleteOptions{}
+			return tc.KubeClient.CoreV1().Secrets(OpenshiftLoggingNS).Delete(context.TODO(), receiverName, opts)
 		})
 		container.VolumeMounts = append(container.VolumeMounts, corev1.VolumeMount{
 			Name:      "certs",
@@ -284,7 +321,9 @@ func (tc *E2ETestFramework) DeployFluentdReceiver(rootDir string, secure bool) (
 		})
 		podSpec.Containers = []corev1.Container{container}
 		logStore.pipelineSecret.Data["shared_key"] = []byte("fluent-receiver")
-		if logStore.pipelineSecret, err = tc.KubeClient.Core().Secrets(OpenshiftLoggingNS).Update(logStore.pipelineSecret); err != nil {
+
+		opts := metav1.UpdateOptions{}
+		if logStore.pipelineSecret, err = tc.KubeClient.CoreV1().Secrets(OpenshiftLoggingNS).Update(context.TODO(), logStore.pipelineSecret, opts); err != nil {
 			return nil, err
 		}
 		podSpec.Volumes = append(podSpec.Volumes, corev1.Volume{
@@ -296,17 +335,20 @@ func (tc *E2ETestFramework) DeployFluentdReceiver(rootDir string, secure bool) (
 		})
 	}
 
+	opts := metav1.CreateOptions{}
 	config := k8shandler.NewConfigMap(container.Name, OpenshiftLoggingNS, map[string]string{
 		"fluent.conf": fluentConf,
 	})
-	config, err = tc.KubeClient.Core().ConfigMaps(OpenshiftLoggingNS).Create(config)
+	config, err = tc.KubeClient.CoreV1().ConfigMaps(OpenshiftLoggingNS).Create(context.TODO(), config, opts)
 	if err != nil {
 		return nil, err
 	}
 	tc.AddCleanup(func() error {
-		return tc.KubeClient.Core().ConfigMaps(OpenshiftLoggingNS).Delete(config.Name, nil)
+		opts := metav1.DeleteOptions{}
+		return tc.KubeClient.CoreV1().ConfigMaps(OpenshiftLoggingNS).Delete(context.TODO(), config.Name, opts)
 	})
 
+	dOpts := metav1.CreateOptions{}
 	fluentDeployment := k8shandler.NewDeployment(
 		container.Name,
 		OpenshiftLoggingNS,
@@ -315,7 +357,7 @@ func (tc *E2ETestFramework) DeployFluentdReceiver(rootDir string, secure bool) (
 		podSpec,
 	)
 
-	fluentDeployment, err = tc.KubeClient.Apps().Deployments(OpenshiftLoggingNS).Create(fluentDeployment)
+	fluentDeployment, err = tc.KubeClient.AppsV1().Deployments(OpenshiftLoggingNS).Create(context.TODO(), fluentDeployment, dOpts)
 	if err != nil {
 		return nil, err
 	}
@@ -329,21 +371,40 @@ func (tc *E2ETestFramework) DeployFluentdReceiver(rootDir string, secure bool) (
 			},
 		},
 	)
+
+	tc.AddCleanup(func() error {
+		_, err := oc.Exec().
+			WithNamespace(OpenshiftLoggingNS).
+			WithPodGetter(oc.Get().
+				WithNamespace(OpenshiftLoggingNS).
+				Pod().
+				Selector("component=fluent-receiver").
+				OutputJsonpath("{.items[0].metadata.name}")).
+			Container("fluent-receiver").
+			WithCmd("/bin/sh", "-c", "rm -rf /tmp/app.logs /tmp/app-logs").
+			Run()
+		return err
+	})
+
 	tc.AddCleanup(func() error {
 		var zerograce int64
-		deleteopts := metav1.DeleteOptions{
+		opts := metav1.DeleteOptions{
 			GracePeriodSeconds: &zerograce,
 		}
-		return tc.KubeClient.AppsV1().Deployments(OpenshiftLoggingNS).Delete(fluentDeployment.Name, &deleteopts)
+		return tc.KubeClient.AppsV1().Deployments(OpenshiftLoggingNS).Delete(context.TODO(), fluentDeployment.Name, opts)
 	})
-	service, err = tc.KubeClient.Core().Services(OpenshiftLoggingNS).Create(service)
+
+	sOpts := metav1.CreateOptions{}
+	service, err = tc.KubeClient.CoreV1().Services(OpenshiftLoggingNS).Create(context.TODO(), service, sOpts)
 	if err != nil {
 		return nil, err
 	}
 	tc.AddCleanup(func() error {
-		return tc.KubeClient.Core().Services(OpenshiftLoggingNS).Delete(service.Name, nil)
+		opts := metav1.DeleteOptions{}
+		return tc.KubeClient.CoreV1().Services(OpenshiftLoggingNS).Delete(context.TODO(), service.Name, opts)
 	})
 	logStore.deployment = fluentDeployment
-	tc.LogStore = logStore
+	name := fluentDeployment.GetName()
+	tc.LogStores[name] = logStore
 	return fluentDeployment, tc.waitForDeployment(OpenshiftLoggingNS, fluentDeployment.Name, defaultRetryInterval, defaultTimeout)
 }
